AutoFill class

Constructors

AutoFill({ConditionalOn? condition, required List<Mapping> mappings})
AutoFill.fromMap(Map<String, dynamic> map)
factory

Properties

condition ConditionalOn?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
mappings List<Mapping>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({ConditionalOn? condition, List<Mapping>? mappings}) AutoFill
✅ Add copyWith method
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited