Mapping class

Constructors

Mapping({String? dataType, dynamic sourceValue, String? sourceField, required String targetField, required String type})
Mapping.fromMap(Map<String, dynamic> map)
factory

Properties

dataType String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceField String?
getter/setter pair
sourceValue ↔ dynamic
getter/setter pair
targetField String
getter/setter pair
type String
getter/setter pair

Methods

copyWith({String? dataType, dynamic sourceValue, String? sourceField, String? targetField, String? type}) Mapping
✅ Add copyWith method
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited