menu
craft_ux package
documentation
models/conditional_on.dart
Regex class
Regex class
dark_mode
light_mode
Regex
class
Constructors
Regex
({
required
String
pattern
,
String
?
message
})
Regex.fromMap
(
Map
<
String
,
dynamic
>
map
)
factory
Properties
hashCode
→
int
The hash code for this object.
no setter
inherited
message
↔
String
?
getter/setter pair
pattern
↔
String
getter/setter pair
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
Methods
copyWith
(
{
String
?
pattern
,
String
?
message
})
→
Regex
✅ Add
copyWith
method
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap
(
)
→
Map
<
String
,
dynamic
>
toString
(
)
→
String
A string representation of this object.
inherited
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
craft_ux package
documentation
models/conditional_on
Regex class
conditional_on library