DynamicFieldProps class

Constructors

DynamicFieldProps({required String fieldKey, required Field field, dynamic value, required dynamic onChange(dynamic), String? error, bool? disabled, List<Option>? options})

Properties

disabled bool?
getter/setter pair
error String?
getter/setter pair
field Field
getter/setter pair
fieldKey String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
onChange ↔ dynamic Function(dynamic)
getter/setter pair
options List<Option>?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value ↔ dynamic
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited