DynamicFormProps class

Constructors

DynamicFormProps({required String componentName, required FormDefinition formJson, dynamic existingObject, bool includeSubmit = false, dynamic onSubmitSuccess(dynamic)?})

Properties

componentName String
getter/setter pair
existingObject ↔ dynamic
getter/setter pair
formJson FormDefinition
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
includeSubmit bool
getter/setter pair
onSubmitSuccess ↔ dynamic Function(dynamic)?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited