Source class

Constructors

Source({String? api, bool? alwaysRefresh, String? labelKey, String? valueKey, List<Option>? options})
Source.fromMap(Map<String, dynamic> map)
factory

Properties

alwaysRefresh bool?
getter/setter pair
api String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
labelKey String?
getter/setter pair
options List<Option>?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
valueKey String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited