Validation class
Constructors
- Validation({ConditionalOn? conditionalOn, bool? required, String? message, Regex? regex, int? minLength, int? maxLength, String? min, String? max})
-
Validation.fromMap(Map<
String, dynamic> map) -
factory
Properties
- conditionalOn ↔ ConditionalOn?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- max ↔ String?
-
getter/setter pair
- maxLength ↔ int?
-
getter/setter pair
- message ↔ String?
-
getter/setter pair
- min ↔ String?
-
getter/setter pair
- minLength ↔ int?
-
getter/setter pair
- regex ↔ Regex?
-
getter/setter pair
- required ↔ bool?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited