ConditionalOn class
Constructors
- ConditionalOn({required String field, required List values, String? conditionalValueKey, Regex? regex})
-
ConditionalOn.fromMap(Map<
String, dynamic> map) -
factory
Properties
- conditionalValueKey ↔ String?
-
getter/setter pair
- field ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- regex ↔ Regex?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- values ↔ List
-
getter/setter pair
Methods
-
copyWith(
{String? field, List? values, String? conditionalValueKey, Regex? regex}) → ConditionalOn -
✅ Add
copyWithmethod -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited