Field class
Constructors
-
Field({String? fieldStyle, required String name, String? dataType, String? label, String? placeholder, String? formatter, String? fieldType, dynamic defaultValue, ConditionalOn? disabledOn, bool? disabled, List<
String> ? dependentOn, Validation? validation, List<AutoFill> ? autoFill, List<Option> ? options, Source? source, ConditionalOn? conditionalOn}) -
Field.fromMap(Map<
String, dynamic> map) -
Optionally, you can add a factory method to construct a Field from a Map.
factory
Properties
-
autoFill
↔ List<
AutoFill> ? -
getter/setter pair
- conditionalOn ↔ ConditionalOn?
-
getter/setter pair
- dataType ↔ String?
-
getter/setter pair
- defaultValue ↔ dynamic
-
getter/setter pair
-
dependentOn
↔ List<
String> ? -
getter/setter pair
- disabled ↔ bool?
-
getter/setter pair
- disabledOn ↔ ConditionalOn?
-
getter/setter pair
- fieldStyle ↔ String?
-
getter/setter pair
- fieldType ↔ String?
-
getter/setter pair
- formatter ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
getter/setter pair
- label ↔ String?
-
getter/setter pair
- name ↔ String
-
getter/setter pair
-
options
↔ List<
Option> ? -
getter/setter pair
- placeholder ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source ↔ Source?
-
getter/setter pair
- validation ↔ Validation?
-
getter/setter pair
Methods
-
copyWith(
{String? name, String? label, String? fieldType, String? placeholder, dynamic defaultValue, bool? disabled, ConditionalOn? disabledOn, Validation? validation, Source? source, List< String> ? dependentOn, ConditionalOn? conditionalOn, List<Option> ? options, List<AutoFill> ? autoFill}) → Field -
✅
copyWithmethod to update specific properties -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - Converts this Field to a Map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited