FormDefinition class

Constructors

FormDefinition({String? title, List<Section>? sections, String? sectionStyle, String? formStyle, List<Field>? fields, bool? repeatable, int? startWithIndex, String? formValidation, RequestAction? requestAction, bool? includeIndexCount, bool? mandatoryFirstIndex, int? maxIndex})
FormDefinition.fromMap(Map<String, dynamic> json)
factory

Properties

fields List<Field>?
getter/setter pair
formStyle String?
getter/setter pair
formValidation String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
includeIndexCount bool?
getter/setter pair
mandatoryFirstIndex bool?
getter/setter pair
maxIndex int?
getter/setter pair
repeatable bool?
getter/setter pair
requestAction RequestAction?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sections List<Section>?
getter/setter pair
sectionStyle String?
getter/setter pair
startWithIndex int?
getter/setter pair
title String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited